==> PEAR_2600_X64_LINUX_1.0.0.tar.gz: usr/local/openresty/nginx/lua/network_common.lua <==
local router = require("router")

if (ngx.var.uri == '/network/wan/pppoe/dial') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_pppoe_dial.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(1)
		router.write_config("/etc/router/config/wan_pppoe_dial.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/pppoe/multidial') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_pppoe_multidial.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(2)
		router.write_config("/etc/router/config/wan_pppoe_multidial.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/pppoe/multiwan') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_pppoe_multiwan.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(3)
		router.write_config("/etc/router/config/wan_pppoe_multiwan.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/dhcp') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_dhcp.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(4)
		router.write_config("/etc/router/config/wan_dhcp.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/static') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_static.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(5)
		router.write_config("/etc/router/config/wan_static.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/bridge') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_bridge.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(6)
		router.write_config("/etc/router/config/wan_bridge.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/method') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_method.json")
	end
elseif (ngx.var.uri == '/network/wireless/2g') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wireless_2g.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.write_config("/etc/router/config/wireless_2g.json", "/etc/router/scripts/start_wireless_2g.sh")
	end
elseif (ngx.var.uri == '/network/wireless/5g') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wireless_5g.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.write_config("/etc/router/config/wireless_5g.json", "/etc/router/scripts/start_wireless_5g.sh")
	end
elseif (ngx.var.uri == '/network/lan/gateway') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/lan_gateway.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.write_config("/etc/router/config/lan_gateway.json", "/etc/router/scripts/start_lan.sh")
	end
elseif (ngx.var.uri == '/network/lan/dhcp') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/lan_dhcp.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.write_config("/etc/router/config/lan_dhcp.json", "/etc/router/scripts/start_lan.sh")
	end
elseif (ngx.var.uri == '/network/lan/devices') then
	if (ngx.var.request_method == 'GET') then
		local cjson = require("cjson")
		local devices = {}
		setmetatable(devices, cjson.empty_array_mt)
		local file = io.open("/etc/router/tmp/dnsmasq.leases", "r");
		for str in file:lines() do
			local macaddr, ipaddr, devname = string.match(str, "^[%d]+%s([%x:]+)%s([%d.]+)%s([^%s]+)")
			local device = {}
			device["devname"] = devname
			device["ipaddr"] = ipaddr
			device["macaddr"] = macaddr
			table.insert(devices, device)
		end
		local resp = cjson.encode(devices)
		ngx.say(resp)
	end
elseif (ngx.var.uri == '/network/lan/device/status') then
	if (ngx.var.request_method == 'GET') then
		local cjson = require("cjson")
		local ipaddr = ngx.var.arg_ipaddr
		if (ipaddr == nil) then
			router.process_error(5, "server get url args failed!")
			return
		end
		local online = 0
		local os_ret = os.execute("arping -c 1 "..ipaddr)
		if (os_ret == true) then
			online = 1
		end
		local temp = {}
		temp["ipaddr"] = ipaddr
		temp["online"] = online
		local resp = cjson.encode(temp)
		ngx.say(resp)
	end
else
	router.process_error(1, "invalid uri: "..ngx.var.uri)
end

==> PEAR_2600_X64_LINUX_1.0.1.tar.gz: usr/local/openresty/nginx/lua/network_common.lua <==
local router = require("router")

function scan_wireless_hotspots()
	local os_ret = os.execute("/etc/router/scripts/scan_wireless_hotspots.sh")
	if (os_ret == nil) then
		router.process_error(3, "server operation failed!")
		return -1
	end

	local file = io.popen("cat /etc/router/run/scan_result.txt | grep ESSID  | awk -F: '{print $2}' | sed 's/\"//g'")
	local index = 0
	local ssid = {}
	for str in file:lines() do
		index = index + 1
		ssid[index] = str
	end
	local num = index

	file = io.popen("cat /etc/router/run/scan_result.txt | grep 'Encryption key' | awk -F: '{print $2}'")
	index = 0
	local encryption = {}
	for str in file:lines() do
		index = index + 1
		encryption[index] = str
	end

	file = io.popen("cat /etc/router/run/scan_result.txt | grep 'Signal level'|awk -F= '{print $3}' | awk  '{print $1}'")
	index = 0
	local signal = {}
	for str in file:lines() do
		index = index + 1
		quality = (tonumber(str) + 100) * 2
		if (quality > 100) then
			quality = 100
		end
		if (quality < 0) then
			quality = 0
		end
		signal[index] = quality
	end

	file = io.popen("cat /etc/router/run/scan_result.txt | grep Channel: | awk -F: '{print $2}'")
	index = 0
	local channel = {}
	for str in file:lines() do
		index = index + 1
		channel[index] = tonumber(str)
	end

	local cjson = require("cjson")
	local hotspot_list = {}
	setmetatable(hotspot_list, cjson.empty_array_mt)
	for i = 1, num do
		local hotspot = {}
		hotspot["ssid"] = ssid[i]
		hotspot["encryption"] = encryption[i]
		hotspot["quality"] = signal[i]
		hotspot["channel"] = channel[i]
		table.insert(hotspot_list, hotspot)
	end

	local temp = {}
	temp["result"] = hotspot_list
	local resp = cjson.encode(temp)
	ngx.say(resp)
end

if (ngx.var.uri == '/network/wan/pppoe/dial') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_pppoe_dial.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(1)
		router.write_config("/etc/router/config/wan_pppoe_dial.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/pppoe/multidial') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_pppoe_multidial.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(2)
		router.write_config("/etc/router/config/wan_pppoe_multidial.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/pppoe/multiwan') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_pppoe_multiwan.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(3)
		router.write_config("/etc/router/config/wan_pppoe_multiwan.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/dhcp') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_dhcp.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(4)
		router.write_config("/etc/router/config/wan_dhcp.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/static') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_static.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(5)
		router.write_config("/etc/router/config/wan_static.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/bridge') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_bridge.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(6)
		router.write_config("/etc/router/config/wan_bridge.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/wireless/repeater') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_wireless_repeater.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.set_wan_method(7)
		router.write_config("/etc/router/config/wan_wireless_repeater.json", "/etc/router/scripts/start_wan.sh")
	end
elseif (ngx.var.uri == '/network/wan/method') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wan_method.json")
	end
elseif (ngx.var.uri == '/network/wireless/2g') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wireless_2g.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.write_config("/etc/router/config/wireless_2g.json", "/etc/router/scripts/start_wireless_2g.sh")
	end
elseif (ngx.var.uri == '/network/wireless/5g') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/wireless_5g.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.write_config("/etc/router/config/wireless_5g.json", "/etc/router/scripts/start_wireless_5g.sh")
	end
elseif (ngx.var.uri == '/network/wireless/hotspots') then
	if (ngx.var.request_method == 'GET') then
		scan_wireless_hotspots()
	end
elseif (ngx.var.uri == '/network/lan/gateway') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/lan_gateway.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.write_config("/etc/router/config/lan_gateway.json", "/etc/router/scripts/start_lan.sh")
	end
elseif (ngx.var.uri == '/network/lan/dhcp') then
	if (ngx.var.request_method == 'GET') then
		router.read_config("/etc/router/config/lan_dhcp.json")
	elseif (ngx.var.request_method == 'PUT') then
		router.write_config("/etc/router/config/lan_dhcp.json", "/etc/router/scripts/start_lan.sh")
	end
elseif (ngx.var.uri == '/network/lan/devices') then
	if (ngx.var.request_method == 'GET') then
		local cjson = require("cjson")
		local devices = {}
		setmetatable(devices, cjson.empty_array_mt)
		local file = io.open("/etc/router/run/dnsmasq.leases", "r");
		for str in file:lines() do
			local macaddr, ipaddr, devname = string.match(str, "^[%d]+%s([%x:]+)%s([%d.]+)%s([^%s]+)")
			local device = {}
			device["devname"] = devname
			device["ipaddr"] = ipaddr
			device["macaddr"] = macaddr
			table.insert(devices, device)
		end
		local resp = cjson.encode(devices)
		ngx.say(resp)
	end
elseif (ngx.var.uri == '/network/lan/device/status') then
	if (ngx.var.request_method == 'GET') then
		local cjson = require("cjson")
		local ipaddr = ngx.var.arg_ipaddr
		if (ipaddr == nil) then
			router.process_error(5, "server get url args failed!")
			return
		end
		local online = 0
		local os_ret = os.execute("arping -c 1 "..ipaddr)
		if (os_ret == true) then
			online = 1
		end
		local temp = {}
		temp["ipaddr"] = ipaddr
		temp["online"] = online
		local resp = cjson.encode(temp)
		ngx.say(resp)
	end
else
	router.process_error(1, "invalid uri: "..ngx.var.uri)
end
